霸王别姬 (豆瓣)
Description: 霸王别姬电影简介和剧情介绍,霸王别姬影评、图片、预告片、影讯、论坛、在线购票
Keywords: 霸王别姬,霸王别姬,霸王别姬影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.2豆瓣电影Top250

# 霸王别姬 (1993)

更新描述或海报

导演: 陈凯歌
编剧: 芦苇 / 李碧华
主演: 张国荣 / 张丰毅 / 巩俐 / 葛优 / 英达 / 蒋雯丽 / 吴大维 / 吕齐 / 雷汉 / 尹治 / 马明威 / 费振翔 / 智一桐 / 李春 / 赵海龙 / 李丹 / 童弟 / 沈慧芬 / 黄斐 / 徐杰
类型: 剧情 / 爱情 / 同性
制片国家/地区: 中国大陆 / 中国香港
语言: 汉语普通话
上映日期: 1993-07-26(中国大陆) / 1993-01-01(中国香港)
片长: 171分钟 / 155分钟(美国剧场版)
又名: 再见，我的妾 / Farewell My Concubine / Adieu Ma Concubine
IMDb: tt0106332
豆瓣评分
引用
9.6
2030252人评价
5星
82.4%
4星
15.4%
3星
1.9%
2星
0.1%
1星
0.1%
好友评分
你关注的人看过这部作品的平均分
9.0
4人评价
我看过这部电影 2020-07-12 修改
我的评价:
推荐

## 霸王别姬的剧情简介 · · · · · ·

段小楼（张丰毅）与程蝶衣（张国荣）是一对打小一起长大的师兄弟，两人一个演生，一个饰旦，一向配合天衣无缝，尤其一出《霸王别姬》，更是誉满京城，为此，两人约定合演一辈子《霸王别姬》。但两人对戏剧与人生关系的理解有本质不同，段小楼深知戏非人生，程蝶衣则是人戏不分。
段小楼在认为该成家立业之时迎娶了名妓菊仙（巩俐），致使程蝶衣认定菊仙是可耻的第三者，使段小楼做了叛徒，自此，三人围绕一出《霸王别姬》生出的爱恨情仇战开始随着时代风云的变迁不断升级，终酿成悲剧。 ©豆瓣

## 霸王别姬的演职员 · · · · · · ( 全部 58 )

- 陈凯歌 导演
- 张国荣 饰 程蝶衣
- 张丰毅 饰 段小楼
- 巩俐 饰 菊仙
- 葛优 饰 袁四爷
- 英达 饰 那坤

## 霸王别姬的视频和图片 · · · · · · ( 预告片7 | 视频评论2 · 添加 | 图片2161 · 添加 )

## 霸王别姬的获奖情况 · · · · · · ( 全部 )

- 第66届奥斯卡金像奖
- 最佳外语片(提名)
- 陈凯歌

- 第46届戛纳电影节
- 主竞赛单元 金棕榈奖
- 陈凯歌

- 第51届金球奖
- 电影类 最佳外语片

## 喜欢这部电影的人也喜欢 · · · · · ·

  春光乍泄

  罗马假日

  重庆森林

  花样年华

  泰坦尼克号

  断背山

  爱在黎明破晓前

  甜蜜蜜

  请以你的名字呼唤我

  天使爱美丽

我要写短评

## 霸王别姬的短评 · · · · · · ( 全部 434339 条 )

热门 / 最新 / 好友

### 36298 有用 phoebe 看过 2007-11-21 20:38:33

陈凯歌可以靠它吃两辈子饭了，现在看来江郎才尽也情有可原

### 23983 有用 沉歌 看过 2007-10-14 15:39:21

他竟当面一语点破：虞姬是真虞姬，霸王是假霸王。

### 31414 有用 老鸡｜扶立 看过 2008-01-10 16:26:02

在野路子出身的张国荣面前，学院出身的张丰毅显得那么单薄

### 16194 有用 蚂蚁没问题 看过 2009-07-13 23:47:06

就凭这个，我愿意原谅陈凯歌一切的烂片 你只要伟大过一次就可以了 就凭这个 哥哥你是我心中永远不朽的传奇 你是全世界最大的角儿

### 15015 有用 kingfish 看过 2006-03-22 12:32:08

不解,拍出过霸王别姬的人怎能拍出无极来

> 更多短评 434339条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。

### 1 有用 LLudeer 看过 2020-12-06 23:54:54

终于可以在别人问我看没看过这部电影的时候说“看过”了！！！被深深震撼了......往事不要再提，人生已多风雨。（有人和我说这部其实是陈凯歌他爸拍的？以及，葛优的眼睛为什么可以做到完全不眨！

我要写影评

## 霸王别姬的影评 · · · · · · ( 全部 9410 条 )

热门 / 最新 / 好友
陈野犁 2008-05-15 11:01:55

## 最懂蝶衣袁四爷

李碧华名作《霸王别姬》，我没看过原著，只看了电影。之前东鳞西爪地听人讲过这故事，略有了解。又在电视里瞥到几眼片段。一直耿耿于怀。为了表示对这部向往已久的好片子的尊重，破天荒地买了正版影碟。然后在一个冬夜裹着棉被捧着红茶看完。 如一切李氏作品，于沧桑倒转岁月... (展开)
24229 1375 1947回应 收起
psyduck 2006-02-14 13:24:16

## 关于《霸王别姬》-

又看《霸王别姬》，不一样的环境，一样的感动。 有几大矛盾对象： 程蝶衣与段小楼 蝶衣从最开始进京剧班，就与小楼有着很深厚的感情。我们可以看到许多感人的画面：小楼受罚，黑夜冬天在院子了跪着，蝶衣则隔着窗子心疼地看着他，等小楼回来后则自己光着身子，却把被子给小楼裹... (展开)
13398 1141 851回应 收起
阿底 2006-06-02 11:17:16

## 迷恋与背叛——[霸王别姬]

必须承认，在看这部电影之前，对国产电影有种本能的偏见，认为就是拍不过人家的大导演，拍不出人家的大手笔。当然，其实这是谬论。现在不用谁站出来批判一下我的这种情节，我自己也会毫不客气的承认。 从前对张国荣一直都没有感觉，可在[霸王别姬]里，每每看到他，都... (展开)
5651 322 365回应 收起
从嘉 2008-04-19 01:14:40

## 胡说霸王别姬

程蝶衣：阉割的完成 和我一起看电影的某个纯洁善良的小孩，看到小豆子被“咔”的一下剁掉了多余的手指时，作不忍目睹状。而我则一脸坏笑地想起一个词：阉割。我始终认为剁手指的一场戏在剧中一定有它的象征意义，否则根本无需设置小豆子的六指，也丝毫不影响叙事情节的进展。 ... (展开)
4807 195 238回应 收起
火龙果不耐受者 2007-11-12 20:45:00

## 戏梦人生

·张国荣能接《霸王别姬》很大程度上要感谢黄百鸣：当时张国荣是东方院线的签约艺员，本来不可以去接拍其它公司的电影，但是作为老板的黄百鸣不但不做限制，反而大力鼓动他去接下此戏，说剧本实在太好了，“会成为你一生的代表作”，这种体贴和大度在商业社会里是非常少见的。... (展开)
2017 65 162回应 收起
燕麦麦 2019-03-15 17:17:43 #《霸王别姬》中人物前后的性格发生了怎样的转变？

## 《霸王别姬》里的角色众生相

这篇影评可能有剧透

1. 小癞子 这个从电影一开篇，就在逮机会逃跑的小孩，一句“小癞子又跑了”，道尽了他是个逃跑的惯犯。 随着戏班剧情展开，我们会看到小癞子的日常，就是没完没了的犯错，无穷无尽的挨打。 小癞子，就是那种资质较差，童心未泯，有点调皮捣蛋的孩子，所以他挨得打比谁都多，逃... (展开)
2403 11 114回应 收起
何颜对故人 2007-09-27 13:28:27

## 从另一角度看《霸王别姬》

仔细看了很多朋友评《霸王别姬》都是从宏观上来看整部电影，或许是处于某些原因，有些话不敢说，但是我认为评电影，论史实不能回避问题，一团和气。下面简单说说我的一点看法。 李碧华原著开始就是一句——婊子无情，戏子无义。 先说一说里面的两位性工作者，... (展开)
1721 106 142回应 收起
♣王王 2009-01-01 09:33:31

## 霸王别姬电影分析（一次作业）

关于影片《霸王别姬》的分析 文学阐述 如果对《霸王别姬》用画框连缀起来的空间进行审视，陈凯歌将他的影片故事时间从1924年北洋军阀统治时期延续到文革以后，是一个横跨了半个多世纪的近代历史。在这里历史是作为人物际遇的背景，给影响空间融入时间的剧烈变动。《霸王别姬... (展开)
1618 69 98回应 收起
小之 2009-01-11 00:35:51

## 张国荣评《霸王别姬》

这篇影评可能有剧透

對談人：關錦鵬、張國榮 去年（一九九五），關錦鵬應英國大英電影協會（BFI．British Film Institute）之邀，擔任 [紀念電影一百年全球訪談系列紀紀錄片]兩岸三地部分的製作人，為了這個重大的任務，關錦鵬走访了許多極具關鍵地位的電影工作者。 張國榮是九O年代華裔男演員... (展开)
761 23 91回应 收起

> 更多影评 9410篇

添加新讨论

## 讨论区 · · · · · ·

推荐 | 来自小乖＆可乐 |  | 2022-11-24 18:58:14
解放军看戏那场，是蝶衣自己失声吗？ | 来自megastar | 16 回应 | 2022-11-24 13:03:41
这部电影是耽美？ | 来自国民小仙女💫 | 34 回应 | 2022-11-23 12:43:06
真有那么好？ | 来自湿人1995 | 274 回应 | 2022-11-23 01:41:39
张国荣粉丝收敛一点吧 | 来自momo | 41 回应 | 2022-11-21 23:43:26

> 去这部影片的讨论区（全部2087条）

## 关于《霸王别姬》的问题 · · · · · · ( 全部111个 )

- 小豆子的母亲是菊仙吗？ 25人回答
- 关于程蝶衣少年是总唱错，“我本是男儿身”？ 14人回答

> 全部111个问题

## 在哪儿看这部电影 · · · · · ·

报错

- 腾讯视频 免费观看
- 芒果TV 免费观看
- 西瓜视频 免费观看
- 1905电影网 免费观看
- 哔哩哔哩 免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 深情即是一桩悲剧，必得以死来句读。 (眠去)
- 文艺女王必修课「华语篇」 (不良生)
- 电影学院本科生必看100部 (志国)
- He loves a man, she loves a woman(1/2) (影志)

## 谁在看这部电影 · · · · · ·

- 唔昂（考公ing
  刚刚 看过
- 羽勋~_~
  刚刚 看过
- momo
  1分钟前 看过

3404985人看过 / 413279人想看

订阅霸王别姬的评论:
feed: rss 2.0